/* Code for Bellemare, Marc F., "Sharecropping,		*/
/* Insecure Land Rights, and Land Titling Policies:	*/
/* A Case Study of Lac Alaotra, Madagascar		*/

/* Code Author: Marc F. Bellemare			*/
/* Assistant Professor of Public Policy			*/
/* and Economics, Duke University			*/

/* This Version: July 13, 2009				*/


clear
drop _all
set mem 256m

use "C:\BellemareSharecroppingCaseStudy.dta"


gen rst_full = 1 if y_2==1 & (P_assets_pc < A_assets_pc)
replace rst_full = 0 if rst==.

gen rt_full = 1 if P_assets_pc < A_assets_pc
replace rt_full = 0 if P_assets_pc >= A_assets_pc

gen sharecrop_full = 1 if y_2==1
replace sharecrop_full = 0 if y_2~=1

gen fixedrent_full = 1 if y_2==0
replace fixedrent_full = 0 if y_2~=0

gen sharecrop = 1 if y_2==1
replace sharecrop = 0 if y_2==0

gen fixedrent = 1 if y_2==0
replace fixedrent = 0 if y_2==1

gen rt = 1 if P_assets_pc < A_assets_pc
replace rt = 0 if P_assets_pc >= A_assets_pc

gen rst = 1 if y_2==1 & (P_assets_pc < A_assets_pc)
replace rst = 0 if y_2==0 | (y_2==1 & A_assets_pc >= A_assets_pc)

log using "C:\BellemareSharecroppingCaseStudy", replace



/* Table 1						*/

mean y_1 [pweight=weight], level(99)
mean sharecrop_full [pweight=weight], level(99)
mean fixedrent_full [pweight=weight], level(99)
mean rt_full [pweight=weight], level(99)
mean rst_full [pweight=weight], level(99)
mean sharecrop [pweight=weight], level(99)
mean fixedrent [pweight=weight], level(99)
mean rst [pweight=weight], level(99)



/* Table 2						*/


mean L_hhsize [pweight=weight], level(99)
mean L_hunder15 [pweight=weight], level(99)
mean L_h1564 [pweight=weight], level(99)
mean L_hover64 [pweight=weight], level(99)
mean L_depr [pweight=weight], level(99)

mean L_liq_cons [pweight=weight], level(99)
mean L_wrk_cap [pweight=weight], level(99)
mean L_assets_pc [pweight=weight], level(99)
mean L_income_pc [pweight=weight], level(99)
mean land_pred [pweight=weight], level(99)

mean L_age [pweight=weight], level(99)
mean L_female [pweight=weight], level(99)
mean L_single [pweight=weight], level(99)
mean L_sihanaka [pweight=weight], level(99)
mean L_expag [pweight=weight], level(99)

mean L_mohhlan [pweight=weight], level(99)
mean L_monfag [pweight=weight], level(99)
mean L_monoag [pweight=weight], level(99)
mean L_monowk [pweight=weight], level(99)
mean L_wage [pweight=weight], level(99)
mean L_fady [pweight=weight], level(99)

mean c1 [pweight=weight], level(99)
mean c2 [pweight=weight], level(99)
mean c3 [pweight=weight], level(99)
mean c4 [pweight=weight], level(99)
mean c5 [pweight=weight], level(99)
mean c6 [pweight=weight], level(99)



/* Table 3						*/

mean L_area [pweight=weight], level(99)
mean L_disthous [pweight=weight], level(99)
mean L_distroad [pweight=weight], level(99)
mean L_irrig [pweight=weight], level(99)
xi: mean i.L_irsource [pweight=weight], level(99) 
mean L_title [pweight=weight], level(99)
mean L_years [pweight=weight], level(99)
xi: mean i.L_obtain [pweight=weight], level(99) 
mean L_property [pweight=weight], level(99)
mean L_weakprop [pweight=weight], level(99)
mean rent_are [pweight=weight], level(99)
mean L_cseason [pweight=weight], level(99)
mean L_cseacrop [pweight=weight], level(99)
xi: mean i.L_nocsprob [pweight=weight], level(99) 
xi: mean i.L_soiltype [pweight=weight], level(99) 
xi: mean i.L_slope [pweight=weight], level(99) 
xi: mean i.L_protect [pweight=weight], level(99)
mean L_raindays [pweight=weight], level(99)
xi: mean i.L_soilchar [pweight=weight], level(99)
gen L_price = L_expprice/L_area
mean L_price [pweight=weight], level(99)
mean L_fadyplot [pweight=weight], level(99)
mean L_invest [pweight=weight], level(99)
mean y_1 [pweight=weight], level(99)



/* Table 4						*/

mean P_hhsize if y_1==1 [pweight=weight], level(99)
mean P_hunder15 if y_1==1 [pweight=weight], level(99)
mean P_h1564 if y_1==1 [pweight=weight], level(99)
mean P_hover64 if y_1==1 [pweight=weight], level(99)
mean P_depr if y_1==1 [pweight=weight], level(99)
mean P_liq_cons if y_1==1 [pweight=weight], level(99)
mean P_wrk_cap if y_1==1 [pweight=weight], level(99)
mean P_assets_pc if y_1==1 [pweight=weight], level(99)
mean P_income_pc if y_1==1 [pweight=weight], level(99)
mean P_age if y_1==1 [pweight=weight], level(99)
mean P_female if y_1==1 [pweight=weight], level(99)
mean P_single if y_1==1 [pweight=weight], level(99)
mean P_sihanaka if y_1==1 [pweight=weight], level(99)
mean P_expag if y_1==1 [pweight=weight], level(99)
mean P_mohhlan [pweight=weight], level(99)
mean P_monfag [pweight=weight], level(99)
mean P_monoag [pweight=weight], level(99)
mean P_monowk [pweight=weight], level(99)
mean P_wage [pweight=weight], level(99)
mean P_fady [pweight=weight], level(99)

mean A_hhsize if y_1==1 [pweight=weight], level(99)
mean A_hunder15 if y_1==1 [pweight=weight], level(99)
mean A_h1564 if y_1==1 [pweight=weight], level(99)
mean A_hover64 if y_1==1 [pweight=weight], level(99)
mean A_depr if y_1==1 [pweight=weight], level(99)
mean A_liq_cons if y_1==1 [pweight=weight], level(99)
mean A_wrk_cap if y_1==1 [pweight=weight], level(99)
mean A_assets_pc if y_1==1 [pweight=weight], level(99)
mean A_income_pc if y_1==1 [pweight=weight], level(99)
mean A_age if y_1==1 [pweight=weight], level(99)
mean A_female if y_1==1 [pweight=weight], level(99)
mean A_single if y_1==1 [pweight=weight], level(99)
mean A_sihanaka if y_1==1 [pweight=weight], level(99)
mean A_expag if y_1==1 [pweight=weight], level(99)
mean A_mohhlan [pweight=weight], level(99)
mean A_monfag [pweight=weight], level(99)
mean A_monoag [pweight=weight], level(99)
mean A_monowk [pweight=weight], level(99)
mean A_wage [pweight=weight], level(99)
mean A_fady [pweight=weight], level(99)

ttest P_hhsize == A_hhsize
ttest P_hunder15 == A_hunder15
ttest P_h1564 == A_h1564
ttest P_hover64 == A_hover64
ttest P_depr == A_depr
ttest P_liq_cons == A_liq_cons
ttest P_wrk_cap == A_wrk_cap
ttest P_assets_pc == A_assets_pc
ttest P_income_pc == A_income_pc
ttest P_age == A_age
ttest P_female == A_female
ttest P_single == A_single
ttest P_sihanaka == A_sihanaka
ttest P_expag == A_expag
ttest P_mohhlan == A_mohhlan
ttest P_monfag == A_monfag
ttest P_monoag == A_monoag
ttest P_monowk == A_monowk
ttest P_wage == A_wage
ttest P_fady == A_fady



/* Table 5						*/

xi: mean i.P_palink if y_1==1 [pweight=weight], level(99)
mean P_timelook if y_1==1 [pweight=weight], level(99)
mean P_nego if y_1==1 [pweight=weight], level(99)
xi: mean i.P_negoday if y_1==1 [pweight=weight], level(99)
xi: mean i.P_offerp1 if y_1==1 [pweight=weight], level(99)
xi: mean i.P_offera1 if y_1==1 [pweight=weight], level(99)
mean P_othera if y_1==1 [pweight=weight], level(99)
xi: mean i.P_reasona if y_1==1 [pweight=weight], level(99)
mean P_othtent if y_1==1 [pweight=weight], level(99)
mean P_length if y_1==1 [pweight=weight], level(99)
mean P_duration if y_1==1 [pweight=weight], level(99)

xi: mean i.P_palink if y_1==1 & P_assets_pc < A_assets_pc [pweight=weight], level(99)
mean P_timelook if y_1==1 & P_assets_pc < A_assets_pc [pweight=weight], level(99)
mean P_nego if y_1==1 & P_assets_pc < A_assets_pc [pweight=weight], level(99)
xi: mean i.P_negoday if y_1==1 & P_assets_pc < A_assets_pc [pweight=weight], level(99)
xi: mean i.P_offerp1 if y_1==1 & P_assets_pc < A_assets_pc [pweight=weight], level(99)
xi: mean i.P_offera1 if y_1==1 & P_assets_pc < A_assets_pc [pweight=weight], level(99)
mean P_othera if y_1==1 & P_assets_pc < A_assets_pc [pweight=weight], level(99)
xi: mean i.P_reasona if y_1==1 & P_assets_pc < A_assets_pc [pweight=weight], level(99)
mean P_othtent if y_1==1 & P_assets_pc < A_assets_pc [pweight=weight], level(99)
mean P_length if y_1==1 & P_assets_pc < A_assets_pc [pweight=weight], level(99)
mean P_duration if y_1==1 & P_assets_pc < A_assets_pc [pweight=weight], level(99)

gen P_palink_1 = 1 if P_palink==1
replace P_palink_1 = 0 if P_palink~=1 & P_palink~=.
gen P_palink_2 = 1 if P_palink==2
replace P_palink_2 = 0 if P_palink~=2 & P_palink~=.
gen P_palink_3 = 1 if P_palink==3
replace P_palink_3 = 0 if P_palink~=3 & P_palink~=.
gen P_palink_4 = 1 if P_palink==4
replace P_palink_4 = 0 if P_palink~=4 & P_palink~=.

ttest P_palink_1, by(rt)
ttest P_palink_2, by(rt)
ttest P_palink_3, by(rt)
ttest P_palink_4, by(rt)

ttest P_timelook, by(rt)
ttest P_nego, by(rt)

gen P_negoday_0 = 1 if P_negoday==0
replace P_negoday_0 = 0 if P_negoday~=0 & P_negoday~=.
gen P_negoday_1 = 1 if P_negoday==1
replace P_negoday_1 = 0 if P_negoday~=1 & P_negoday~=.
gen P_negoday_2 = 1 if P_negoday==2
replace P_negoday_2 = 0 if P_negoday~=2 & P_negoday~=.
gen P_negoday_3 = 1 if P_negoday==3
replace P_negoday_3 = 0 if P_negoday~=3 & P_negoday~=.

ttest P_negoday_0, by(rt)
ttest P_negoday_1, by(rt)
ttest P_negoday_2, by(rt)
ttest P_negoday_3, by(rt)

gen P_offerp1_1 = 1 if P_offerp1==1
replace P_offerp1_1 = 0 if P_offerp1~=1 & P_offerp1~=.
gen P_offerp1_2 = 1 if P_offerp1==2
replace P_offerp1_2 = 0 if P_offerp1~=2 & P_offerp1~=.
gen P_offerp1_3 = 1 if P_offerp1==3
replace P_offerp1_3 = 0 if P_offerp1~=3 & P_offerp1~=.
gen P_offerp1_4 = 1 if P_offerp1==4
replace P_offerp1_4 = 0 if P_offerp1~=4 & P_offerp1~=.
gen P_offerp1_5 = 1 if P_offerp1==5
replace P_offerp1_5 = 0 if P_offerp1~=5 & P_offerp1~=.
gen P_offerp1_6 = 1 if P_offerp1==6
replace P_offerp1_6 = 0 if P_offerp1~=6 & P_offerp1~=.
gen P_offerp1_7 = 1 if P_offerp1==7
replace P_offerp1_7 = 0 if P_offerp1~=7 & P_offerp1~=.

ttest P_offerp1_1, by(rt)
ttest P_offerp1_2, by(rt)
ttest P_offerp1_3, by(rt)
ttest P_offerp1_4, by(rt)
ttest P_offerp1_5, by(rt)
ttest P_offerp1_6, by(rt)
ttest P_offerp1_7, by(rt)

gen P_offera1_1 = 1 if P_offera1==1
replace P_offera1_1 = 0 if P_offera1~=1 & P_offera1~=.
gen P_offera1_2 = 1 if P_offera1==2
replace P_offera1_2 = 0 if P_offera1~=2 & P_offera1~=.
gen P_offera1_3 = 1 if P_offera1==3
replace P_offera1_3 = 0 if P_offera1~=3 & P_offera1~=.
gen P_offera1_4 = 1 if P_offera1==4
replace P_offera1_4 = 0 if P_offera1~=4 & P_offera1~=.
gen P_offera1_5 = 1 if P_offera1==5
replace P_offera1_5 = 0 if P_offera1~=5 & P_offera1~=.
gen P_offera1_6 = 1 if P_offera1==6
replace P_offera1_6 = 0 if P_offera1~=6 & P_offera1~=.
gen P_offera1_7 = 1 if P_offera1==7
replace P_offera1_7 = 0 if P_offera1~=7 & P_offera1~=.

ttest P_offera1_1, by(rt)
ttest P_offera1_2, by(rt)
ttest P_offera1_3, by(rt)
ttest P_offera1_4, by(rt)
ttest P_offera1_5, by(rt)
ttest P_offera1_6, by(rt)
ttest P_offera1_7, by(rt)

ttest P_othera, by(rt)

gen P_reasona1_1 = 1 if P_reasona==1
replace P_reasona1_1 = 0 if P_reasona~=1 & P_reasona~=.
gen P_reasona1_2 = 1 if P_reasona==2
replace P_reasona1_2 = 0 if P_reasona~=2 & P_reasona~=.
gen P_reasona1_3 = 1 if P_reasona==3
replace P_reasona1_3 = 0 if P_reasona~=3 & P_reasona~=.
gen P_reasona1_4 = 1 if P_reasona==4
replace P_reasona1_4 = 0 if P_reasona~=4 & P_reasona~=.
gen P_reasona1_5 = 1 if P_reasona==5
replace P_reasona1_5 = 0 if P_reasona~=5 & P_reasona~=.

ttest P_reasona1_1, by(rt)
ttest P_reasona1_2, by(rt)
ttest P_reasona1_3, by(rt)
ttest P_reasona1_4, by(rt)
ttest P_reasona1_5, by(rt)

ttest P_othtent, by(rt)
ttest P_length, by(rt)
ttest P_duration, by(rt)



/* Table 6						*/

replace r_a = -1*r_a

probit y_2 family L_area tanety lowland L_irrig L_disthous P_hhsize P_depr P_age P_female P_wrk_cap P_assets_pc P_income_pc r_a P_length kin A_hhsize A_depr A_age  A_wrk_cap A_assets_pc A_income_pc A_expag if P_assets_pc < A_assets_pc [pweight=weight]

test P_assets_pc A_assets_pc



/* Table 4 (Redux)					*/

keep if rt==1

mean P_hhsize if y_1==1 [pweight=weight], level(99)
mean P_hunder15 if y_1==1 [pweight=weight], level(99)
mean P_h1564 if y_1==1 [pweight=weight], level(99)
mean P_hover64 if y_1==1 [pweight=weight], level(99)
mean P_depr if y_1==1 [pweight=weight], level(99)
mean P_liq_cons if y_1==1 [pweight=weight], level(99)
mean P_wrk_cap if y_1==1 [pweight=weight], level(99)
mean P_assets_pc if y_1==1 [pweight=weight], level(99)
mean P_income_pc if y_1==1 [pweight=weight], level(99)
mean P_age if y_1==1 [pweight=weight], level(99)
mean P_female if y_1==1 [pweight=weight], level(99)
mean P_single if y_1==1 [pweight=weight], level(99)
mean P_sihanaka if y_1==1 [pweight=weight], level(99)
mean P_expag if y_1==1 [pweight=weight], level(99)
mean P_mohhlan [pweight=weight], level(99)
mean P_monfag [pweight=weight], level(99)
mean P_monoag [pweight=weight], level(99)
mean P_monowk [pweight=weight], level(99)
mean P_wage [pweight=weight], level(99)
mean P_fady [pweight=weight], level(99)

mean A_hhsize if y_1==1 [pweight=weight], level(99)
mean A_hunder15 if y_1==1 [pweight=weight], level(99)
mean A_h1564 if y_1==1 [pweight=weight], level(99)
mean A_hover64 if y_1==1 [pweight=weight], level(99)
mean A_depr if y_1==1 [pweight=weight], level(99)
mean A_liq_cons if y_1==1 [pweight=weight], level(99)
mean A_wrk_cap if y_1==1 [pweight=weight], level(99)
mean A_assets_pc if y_1==1 [pweight=weight], level(99)
mean A_income_pc if y_1==1 [pweight=weight], level(99)
mean A_age if y_1==1 [pweight=weight], level(99)
mean A_female if y_1==1 [pweight=weight], level(99)
mean A_single if y_1==1 [pweight=weight], level(99)
mean A_sihanaka if y_1==1 [pweight=weight], level(99)
mean A_expag if y_1==1 [pweight=weight], level(99)
mean A_mohhlan [pweight=weight], level(99)
mean A_monfag [pweight=weight], level(99)
mean A_monoag [pweight=weight], level(99)
mean A_monowk [pweight=weight], level(99)
mean A_wage [pweight=weight], level(99)
mean A_fady [pweight=weight], level(99)

ttest P_hhsize == A_hhsize
ttest P_hunder15 == A_hunder15
ttest P_h1564 == A_h1564
ttest P_hover64 == A_hover64
ttest P_depr == A_depr
ttest P_liq_cons == A_liq_cons
ttest P_wrk_cap == A_wrk_cap
ttest P_assets_pc == A_assets_pc
ttest P_income_pc == A_income_pc
ttest P_age == A_age
ttest P_female == A_female
ttest P_single == A_single
ttest P_sihanaka == A_sihanaka
ttest P_expag == A_expag
ttest P_mohhlan == A_mohhlan
ttest P_monfag == A_monfag
ttest P_monoag == A_monoag
ttest P_monowk == A_monowk
ttest P_wage == A_wage
ttest P_fady == A_fady


log close



